@@ -87,6 +87,16 @@ pub fn populate_base_models(store: &impl Storelike) -> AtomicResult<()> {
     .to_resource()?;
     store.add_resource_unsafe(&requires)?;
 
+    let parent = Property {
+        class_type: Some(urls::PROPERTY.into()),
+        data_type: DataType::AtomicUrl,
+        shortname: "parent".into(),
+        description: "The parent of a Resource sets the hierarchical structure of the Resource, and therefore also the rights / grants. It is used for both navigation, structure and authorization. Parents are the inverse of [children](https://atomicdata.dev/properties/children).".into(),
+        subject: urls::PARENT.into(),
+    }
+    .to_resource()?;
+    store.add_resource_unsafe(&parent)?;
+
     let property = Class {
         requires: vec![urls::SHORTNAME.into(), urls::DATATYPE_PROP.into()],
         recommends: vec![urls::DESCRIPTION.into(), urls::CLASSTYPE_PROP.into(), urls::IS_DYNAMIC.into(), urls::IS_LOCKED.into()],
@@ -118,6 +128,17 @@ pub fn populate_base_models(store: &impl Storelike) -> AtomicResult<()> {
     .to_resource()?;
     store.add_resource_unsafe(&datatype)?;
 
+    let agent = Class {
+        requires: vec![urls::PUBLIC_KEY.into()],
+        recommends: vec![urls::NAME.into(), urls::DESCRIPTION.into()],
+        shortname: "agent".into(),
+        description:
+            "An Agent is a user that can create or modify data. It has two keys: a private and a public one. The private key should be kept secret. The public key is used to verify signatures (on [Commits](https://atomicdata.dev/classes/Commit)) set by the of the Agent.".into(),
+        subject: urls::AGENT.into(),
+    }
+    .to_resource()?;
+    store.add_resource_unsafe(&agent)?;
+
     Ok(())
 }
 
