@@ -33,7 +33,7 @@ pub fn validate_store(
         resource_count += 1;
 
         if fetch_items {
-            match crate::client::fetch_resource(&subject, store) {
+            match crate::client::fetch_resource(subject, store) {
                 Ok(_) => {}
                 Err(e) => unfetchable.push((subject.clone(), e.to_string())),
             }
@@ -62,7 +62,7 @@ pub fn validate_store(
             };
             found_props.push(prop_url.clone());
         }
-        let classes = match store.get_classes_for_subject(&subject) {
+        let classes = match store.get_classes_for_subject(subject) {
             Ok(classes) => classes,
             Err(e) => {
                 unfetchable_classes.push((subject.clone(), e.to_string()));
